Query class

A datastore query.

A query consists of filters (kind, ancestor and property filters), one or more orders and a offset/limit pair.

All fields may be optional.

Example of building a Query: var person = ....; var query = new Query(ancestorKey: personKey, kind: 'Address')

Constructors

Query({Key? ancestorKey, String? kind, List<Filter>? filters, List<Order>? orders, int? offset, int? limit})

Properties

ancestorKey → Key?
Restrict the result set to entities which have this ancestorKey / parent.
final
filters → List<Filter>?
Restrict the result set by a list of property Filters.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String?
Restrict the result set to entities of this kind.
final
limit → int?
Limit the number of entities returned to limit.
final
offset → int?
Skip the first offset entities in the result set.
final
orders → List<Order>?
Order the matching entities following the given property Orders.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited