Transaction class abstract

An opaque token returned by the beginTransaction method of a Datastore.

This token can be passed to the commit and lookup calls if they should operate within this transaction.

Constructors

Transaction()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited