ExpandoModel<T> class abstract

Superclass for all expanded model classes.

The ExpandoModel class adds support for having dynamic properties. You can set arbitrary fields on these models. The expanded values must be values accepted by the ds.Datastore implementation.

Inheritance
Implementers

Constructors

ExpandoModel()

Properties

additionalProperties → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ T?
getter/setter pairinherited
key → Key<T>
no setterinherited
parentKey ↔ Key?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → Object?
Invoked when a nonexistent method or property is accessed.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited