KeyNotFoundException class

Exception that gets thrown when a caller attempts to look up a value by its key, and the key cannot be found in the datastore.

Implemented types

Constructors

KeyNotFoundException(Key key)
Creates a new KeyNotFoundException for the specified key.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key
The Key that was not found in the datastore.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited