ModelDB class abstract

A database of all registered models.

Responsible for converting between dart model objects and datastore entities.

Implementers

Constructors

ModelDB()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fieldNameToPropertyName(String kind, String fieldName) → String?
Returns the property name used for fieldName
fromDatastoreEntity<T extends Model>(Entity? entity) → T?
Converts a ds.Entity to a Model instance.
fromDatastoreKey(Key datastoreKey) → Key
Converts a ds.Key to a Key.
kindName(Type type) → String
Returns the kind name for instances of type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDatastoreEntity(Model model) → Entity
Converts a Model instance to a ds.Entity.
toDatastoreKey(Key dbKey) → Key
Converts a Key to a ds.Key.
toDatastoreValue(String kind, String fieldName, Object? value, {bool forComparison = false}) → Object?
Converts value according to the Property named fieldName in kind.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited