StringListProperty class

A convenience Property for list of strings.

Inheritance

Constructors

StringListProperty({String? propertyName, bool indexed = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexed → bool
Specifies whether this property should be indexed or not.
finalinherited
propertyName → String?
The name of the property.
finalinherited
required → bool
Specifies whether this property is required or not.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subProperty → PrimitiveProperty
finalinherited

Methods

decodePrimitiveValue(ModelDB db, Object? value) → Object
override
encodeValue(ModelDB db, Object? value, {bool forComparison = false}) → Object?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(ModelDB db, Object? value) → bool
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited