Subscription class abstract

A Pub/Sub subscription

A subscription is used to receive messages. A subscriber application create a subscription on a topic to receive messages from it.

Subscriptions can be either pull subscriptions or push subscriptions.

For a pull subscription the receiver calls the Subscription.pull method on the subscription object to get the next message.

For a push subscription a HTTPS endpoint is configured. This endpoint get POST requests with the messages.

Constructors

Subscription()

Properties

absoluteName → String
The absolute name of this subscription.
no setter
endpoint → Uri?
The URI for the push endpoint.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isPull → bool
Whether this is a pull subscription.
no setter
isPush → bool
Whether this is a push subscription.
no setter
name → String
The relative name of this subscription.
no setter
project → String
The name of the project for this subscription.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → Topic
The topic subscribed to.
no setter

Methods

delete() → Future
Delete this subscription.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pull({bool wait = true}) → Future<PullEvent?>
Pull a message from the subscription.
toString() → String
A string representation of this object.
inherited
updatePushConfiguration(Uri endpoint) → Future
Update the push configuration with a new endpoint.

Operators

operator ==(Object other) → bool
The equality operator.
inherited