Topic class abstract

A Pub/Sub topic.

A topic is used by a publisher to publish (send) messages.

Constructors

Topic()

Properties

absoluteName → String
The absolute name of this topic.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
The relative name of this topic.
no setter
project → String
The name of the project for this topic.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future
Delete this topic.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(Message message) → Future
Publish a message.
publishBytes(List<int> message, {Map<String, String> attributes}) → Future
Publish bytes as a message.
publishString(String message, {Map<String, String> attributes}) → Future
Publish a string as a message.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited